@@ -143,8 +143,8 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     try:
         df_raw = pd.read_csv(csv_path[0])
     except pandas.errors.EmptyDataError:
-        print("pandas.errors.EmptyDataError  : " + csv_path[0])
-        quit()
+        raise Exception("pandas.errors.EmptyDataError  : " + csv_path[0])
+
 
     if df_raw.shape[0] == 0:
         print("Empty prompt response file : " + csv_path[0])
